==> walkers-fabric-1.18.2-5.3.3-sources.jar: tocraft/walkers/mixin/client/ShadowMixin.java <==
package tocraft.walkers.mixin.client;

import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_310;
import net.minecraft.class_4538;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_897;
import net.minecraft.class_898;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.ModifyVariable;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import tocraft.walkers.api.PlayerShape;
import tocraft.walkers.mixin.client.accessor.EntityShadowAccessor;

@Environment(EnvType.CLIENT)
@Mixin(value = class_898.class, priority = 999)
public abstract class ShadowMixin {

    @Unique
    private static class_1297 shape_shadowEntity;

    @Inject(
            method = "renderShadow",
            at = @At("HEAD"))
    private static void storeContext(class_4587 matrices, class_4597 vertexConsumers, class_1297 entity, float opacity, float tickDelta, class_4538 world, float radius, CallbackInfo ci) {
        shape_shadowEntity = entity;
    }

    @ModifyVariable(
            method = "renderShadow",
            at = @At(value = "INVOKE", target = "Lnet/minecraft/util/Mth;lerp(DDD)D", ordinal = 0), index = 6, argsOnly = true)
    private static float adjustShadowSize(float originalSize) {
        if (shape_shadowEntity instanceof class_1657 player) {
            class_1309 shape = PlayerShape.getCurrentShape(player);

            if (shape != null) {
                class_897<?> r = class_310.method_1551().method_1561().method_3953(shape);
                float shadowRadius = ((EntityShadowAccessor) r).getShadowRadius();
                float mod = shape.method_6109() ? .5f : 1;
                return shadowRadius * mod;
            }
        }

        return originalSize;
    }
}

==> walkers-fabric-1.20.1-4.2-sources.jar: tocraft/walkers/mixin/client/ShadowMixin.java <==
package tocraft.walkers.mixin.client;

import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_310;
import net.minecraft.class_4538;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_897;
import net.minecraft.class_898;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.ModifyVariable;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import tocraft.walkers.api.PlayerShape;
import tocraft.walkers.mixin.client.accessor.EntityShadowAccessor;

@Environment(EnvType.CLIENT)
@Mixin(value = class_898.class, priority = 999)
public abstract class ShadowMixin {

    @Unique
    private static class_1297 shape_shadowEntity;

    @Inject(
            method = "renderShadow",
            at = @At("HEAD"))
    private static void storeContext(class_4587 matrices, class_4597 vertexConsumers, class_1297 entity, float opacity, float tickDelta, class_4538 world, float radius, CallbackInfo ci) {
        shape_shadowEntity = entity;
    }

    @ModifyVariable(
            method = "renderShadow",
            at = @At(value = "INVOKE", target = "Lnet/minecraft/util/Mth;lerp(DDD)D", ordinal = 0), index = 7)
    private static float adjustShadowSize(float originalSize) {
        if (shape_shadowEntity instanceof class_1657 player) {
            class_1309 shape = PlayerShape.getCurrentShape(player);

            if (shape != null) {
                class_897<?> r = class_310.method_1551().method_1561().method_3953(shape);
                float shadowRadius = ((EntityShadowAccessor) r).getShadowRadius();
                float mod = shape.method_6109() ? .5f : 1;
                return shadowRadius * mod;
            }
        }

        return originalSize;
    }
}
